package com.simuwang.manage.api.system;

import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.pojo.dto.DeleteByIdCmd;
import com.simuwang.base.pojo.dto.UpdateStatusCmd;
import com.simuwang.base.pojo.dto.sys.MenuAddCmd;
import com.simuwang.base.pojo.dto.sys.MenuEditCmd;
import com.simuwang.base.pojo.dto.sys.MenuQuery;
import com.simuwang.base.pojo.vo.sys.SysMenuVO;
import com.simuwang.manage.service.system.SysMenuService;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;

/**
 * 菜单管理相关接口
 */
@RestController
@RequestMapping("/v1/sys/menu")
public class SysMenuController {
    private final SysMenuService service;

    public SysMenuController(SysMenuService service) {
        this.service = service;
    }

    /**
     * 分页接口
     *
     * @param query 菜单列表分页请求参数
     * @return /
     */
    @GetMapping("page")
    public MybatisPage<SysMenuVO> page(MenuQuery query) {
        return this.service.findPage(query);
    }

    /**
     * 新增菜单
     *
     * @param command 菜单信息
     */
    @PostMapping("save")
    public boolean save(@Valid @RequestBody MenuAddCmd command) {
        this.service.insert(command);
        return true;
    }

    /**
     * 更新菜单
     *
     * @param command 菜单id+菜单信息
     */
    @PostMapping("update")
    public boolean update(@Valid @RequestBody MenuEditCmd command) {
        this.service.update(command);
        return true;
    }

    /**
     * 更新菜单状态接口
     *
     * @param command 菜单id+状态对象
     */
    @PostMapping("update-status")
    public boolean updateStatus(@Valid @RequestBody UpdateStatusCmd command) {
        this.service.updateStatus(command);
        return true;
    }

    /**
     * 根据id删除菜单信息接口
     *
     * @param command 菜单id对象
     */
    @PostMapping("del")
    public boolean deleteById(@Valid @RequestBody DeleteByIdCmd command) {
        this.service.delete(command);
        return true;
    }
}
