package com.simuwang.manage.service.impl.system;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.simuwang.base.common.support.service.IService;
import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.common.support.command.BaseAddCmd;
import com.simuwang.base.common.support.command.BaseEditCmd;
import com.simuwang.base.common.support.command.BaseIdCmd;
import com.simuwang.base.common.support.command.BaseIdStatusCmd;
import com.simuwang.base.common.support.query.PageQuery;
import com.simuwang.base.mapper.system.SysMenuMapper;
import com.simuwang.base.pojo.dos.sys.SysMenuDO;
import com.simuwang.base.pojo.dto.sys.MenuAddCmd;
import com.simuwang.base.pojo.dto.sys.MenuEditCmd;
import com.simuwang.base.pojo.dto.sys.MenuQuery;
import com.simuwang.base.pojo.vo.sys.SysMenuVO;
import com.simuwang.manage.service.system.SysMenuService;
import org.springframework.stereotype.Service;

@Service
public class SysMenuServiceImpl implements SysMenuService {
    private final SysMenuMapper mapper;

    public SysMenuServiceImpl(SysMenuMapper mapper) {
        this.mapper = mapper;
    }

    @Override
    public String[] selectColumns() {
        return IService.extColumns(DEFAULT_SELECT_COLUMNS,
                "menu_id", "menu_name", "parent_id", "order_num", "path", "component",
                "query", "is_frame", "is_cache", "menu_type", "visible", "status", "perms", "icon");
    }

    @Override
    public <Q extends PageQuery> void wrapQuery(QueryWrapper<SysMenuDO> wrapper, Q query) {
        MenuQuery params = (MenuQuery) query;
        String keyword = params.getKeyword();
        if (StrUtil.isNotBlank(keyword)) {
            wrapper.like("menu_name", keyword);
        }
        if (params.getStatus() != null) {
            wrapper.eq("status", params.getStatus());
        }
    }

    @Override
    public MybatisPage<SysMenuVO> convertPage(Page<SysMenuDO> page, QueryWrapper<SysMenuDO> wrapper) {
        IPage<SysMenuDO> entityPage = this.mapper.selectPage(page, wrapper);
        return MybatisPage.ofList(entityPage, SysMenuDO::toVo);
    }

    @Override
    public <C extends BaseAddCmd<SysMenuDO>> void insert(C command) {
        MenuAddCmd cmd = (MenuAddCmd) command;
        SysMenuDO entity = cmd.toEntity();
        this.mapper.insert(entity);
    }

    @Override
    public <C extends BaseEditCmd<SysMenuDO>> void update(C command) {
        MenuEditCmd cmd = (MenuEditCmd) command;
        SysMenuDO entity = cmd.toEntity();
        this.mapper.updateById(entity);
    }

    @Override
    public <C extends BaseIdStatusCmd> void updateStatus(C command) {
        SysMenuDO entity = new SysMenuDO();
        entity.setMenuId(command.getId());
        entity.setStatus(command.getStatus());
        this.mapper.updateById(entity);
    }

    @Override
    public <C extends BaseIdCmd> void delete(C command) {
        Integer id = command.getId();
        this.mapper.deleteById(id);
    }
}
